package com.yijia.station.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yijia.station.mapper.StationPicMapper;
import com.yijia.station.domain.StationPic;
import com.yijia.station.service.IStationPicService;

/**
 * 油站支付管理图片Service业务层处理
 * 
 * @author yijia
 * @date 2021-03-19
 */
@Service
public class StationPicServiceImpl implements IStationPicService 
{
    @Autowired
    private StationPicMapper stationPicMapper;

    /**
     * 查询油站支付管理图片
     * 
     * @param id 油站支付管理图片ID
     * @return 油站支付管理图片
     */
    @Override
    public StationPic selectStationPicById(Long id)
    {
        return stationPicMapper.selectStationPicById(id);
    }

    /**
     * 查询油站支付管理图片列表
     * 
     * @param stationPic 油站支付管理图片
     * @return 油站支付管理图片
     */
    @Override
    public List<StationPic> selectStationPicList(StationPic stationPic)
    {
        return stationPicMapper.selectStationPicList(stationPic);
    }

    /**
     * 新增油站支付管理图片
     * 
     * @param stationPic 油站支付管理图片
     * @return 结果
     */
    @Override
    public int insertStationPic(StationPic stationPic)
    {

        return stationPicMapper.insertStationPic(stationPic);
    }

    /**
     * 修改油站支付管理图片
     * 
     * @param stationPic 油站支付管理图片
     * @return 结果
     */
    @Override
    public int updateStationPic(StationPic stationPic)
    {
        return stationPicMapper.updateStationPic(stationPic);
    }

    /**
     * 批量删除油站支付管理图片
     * 
     * @param ids 需要删除的油站支付管理图片ID
     * @return 结果
     */
    @Override
    public int deleteStationPicByIds(Long[] ids)
    {
        return stationPicMapper.deleteStationPicByIds(ids);
    }

    /**
     * 删除油站支付管理图片信息
     * 
     * @param id 油站支付管理图片ID
     * @return 结果
     */
    @Override
    public int deleteStationPicById(Long id)
    {
        return stationPicMapper.deleteStationPicById(id);
    }
}
